@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
 """
 Some models in the merchant's implementation require a many-to-many relation with models from
 outside django-SHOP. Therefore these mapping tables must be materialized by the merchant's
