@@ -1,9 +1,5 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 from django.db import models
-from django.utils.six import with_metaclass
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from filer.fields import image
 
@@ -13,7 +9,7 @@ from shop import deferred
 from shop.models.product import BaseProduct
 
 
-class BaseProductPage(with_metaclass(deferred.ForeignKeyBuilder, models.Model)):
+class BaseProductPage(models.Model, metaclass=deferred.ForeignKeyBuilder):
     """
     ManyToMany relation from the polymorphic Product to the CMS Page.
     This in practice is the category.
@@ -37,7 +33,7 @@ class BaseProductPage(with_metaclass(deferred.ForeignKeyBuilder, models.Model)):
 ProductPageModel = deferred.MaterializedModel(BaseProductPage)
 
 
-class BaseProductImage(with_metaclass(deferred.ForeignKeyBuilder, models.Model)):
+class BaseProductImage(models.Model, metaclass=deferred.ForeignKeyBuilder):
     """
     ManyToMany relation from the polymorphic Product to a set of images.
     """
