@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 from shop.money.money_maker import MoneyMaker, AbstractMoney
 
 # The default Money type for this shop
