@@ -1,8 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
-from django.utils import six
-
 from rest_framework import renderers
 from rest_framework import serializers
 from rest_framework.utils import encoders
@@ -14,10 +9,8 @@ class JSONEncoder(encoders.JSONEncoder):
 
     def default(self, obj):
         if isinstance(obj, AbstractMoney):
-            if six.PY2:
-                return u'{:f}'.format(obj)
             return '{:f}'.format(obj)
-        return super(JSONEncoder, self).default(obj)
+        return super().default(obj)
 
 
 class JSONRenderer(renderers.JSONRenderer):
@@ -29,9 +22,7 @@ class MoneyField(serializers.Field):
 
     def __init__(self, *args, **kwargs):
         kwargs.update(read_only=True)
-        super(MoneyField, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def to_representation(self, obj):
-        if six.PY2:
-            return u'{:f}'.format(obj)
         return '{:f}'.format(obj)
