@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 from rest_framework import serializers
 from shop.conf import app_settings
 from shop.serializers.bases import BaseOrderItemSerializer
