@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 from django.conf.urls import url, include
 from django.http import JsonResponse
 from rest_framework import routers
